@@ -14,11 +14,11 @@ Key Components:
 from cadence_sdk.base.agent import BaseAgent
 from cadence_sdk.base.metadata import ModelConfig, PluginMetadata
 from cadence_sdk.base.plugin import BasePlugin
-from cadence_sdk.registry.plugin_registry import PluginRegistry, discover_plugins, register_plugin
+from cadence_sdk.registry.plugin_registry import PluginRegistry, discover_plugins, get_plugin_registry, register_plugin
 from cadence_sdk.tools.decorators import tool
 from cadence_sdk.tools.registry import ToolRegistry
 
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 __all__ = [
     "BaseAgent",
     "BasePlugin",
@@ -29,4 +29,5 @@ __all__ = [
     "tool",
     "discover_plugins",
     "register_plugin",
+    "get_plugin_registry",
 ]
